
/***********************************************************************
 *
 * marsh.h -   protos for marsh.c
 *
 * $Id: marsh.h 2293 2005-12-03 19:51:13Z rra $
 *
 * $Log$
 * Revision 1.1  1994/06/08 17:28:46  schemers
 * Initial revision
 *
 *
 *----------------------------------------------------------------------
 * Copyright (c) 1994 Board of Trustees, Leland Stanford Jr. University
 ***********************************************************************/

#ifndef MARSH_H
#define MARSH_H

int 
marshall_cred(
       CREDENTIALS *cred,
       char *buffer,
       int max_buff);

int 
unmarshall_cred(
       CREDENTIALS *cred,
       unsigned char *buffer,
       int len);

int marshall_params(
      char *user,
      char *ticketfile,
      char *buffer,
      int  max_buffer);

int unmarshall_params(
      char *user,
      int max_user,
      char *ticketfile,
      int max_ticket,
      unsigned char *buffer,
      int  max_len);

#endif
